@@ -223,7 +223,7 @@ pub fn impl_enum(ast: &syn::DeriveInput, is_internal: bool) -> TokenStream {
             where __S: 'r,
             {
                 let meta = registry.build_enum_type::<#ident>(&(), &[
-                    #(#values)*
+                    #values
                 ]);
                 #meta_description
                 meta.into_meta()
@@ -236,7 +236,7 @@ pub fn impl_enum(ast: &syn::DeriveInput, is_internal: bool) -> TokenStream {
                 _: &#juniper_path::Executor<Self::Context, __S>
             ) -> #juniper_path::Value<__S> {
                 match self {
-                    #(#resolves)*
+                    #resolves
                 }
             }
         }
@@ -248,7 +248,7 @@ pub fn impl_enum(ast: &syn::DeriveInput, is_internal: bool) -> TokenStream {
                 match v.as_enum_value().or_else(|| {
                     v.as_scalar_value::<String>().map(|s| s as &str)
                 }) {
-                    #(#from_inputs)*
+                    #from_inputs
                     _ => None,
                 }
             }
@@ -257,7 +257,7 @@ pub fn impl_enum(ast: &syn::DeriveInput, is_internal: bool) -> TokenStream {
         impl<__S: #juniper_path::ScalarValue> #juniper_path::ToInputValue<__S> for #ident {
             fn to_input_value(&self) -> #juniper_path::InputValue<__S> {
                 match self {
-                    #(#to_inputs)*
+                    #to_inputs
                 }
             }
         }
